import{j as e,v as s,aj as h,U as n,G as i}from"./index-R8nKh668.js";function x(){return e.jsx(s,{children:"Loading..."})}function j({isOpen:t,handleConfirmCloseDecision:a,title:r="Discard changes",description:l="There are unsaved changes in the form. If the editing is cancelled, all changes will be lost.",question:o="Do you want to discard the changes?",confirmLabel:c="Keep editing",cancelLabel:d="Discard changes"}){return e.jsxs(h,{open:t,$width:"32em",children:[e.jsx(n.Header,{children:e.jsx(n.Title,{children:r})}),e.jsxs(n.CustomContent,{children:[e.jsx(s,{children:l}),e.jsx(s,{$marginBottom:"0",children:o})]}),e.jsxs(n.Actions,{children:[e.jsx(i,{label:c,onClick:()=>{a(!1)}}),e.jsx(i,{label:d,variant:"outlined",onClick:()=>{a(!0)}})]})]})}export{j as C,x as L};
