import{t as f,r as w,j as o,d as l,h as _,a as H,b as B,o as I,l as P,s as R,g as $}from"./index-R8nKh668.js";const{colors:b,spacings:{comfortable:m},typography:z}=f,a={typography:{...z.input.label,color:b.text.static_icons__tertiary.rgba},spacings:{left:m.small,right:m.small},states:{disabled:{typography:{color:b.interactive.disabled__text.rgba}}}},M=l.label.withConfig({displayName:"Label__LabelBase",componentId:"sc-1gi2bcn-0"})(["display:flex;justify-content:space-between;align-items:flex-end;position:relative;"," margin-left:",";margin-right:",";color:",";"],_(a.typography),a.spacings.left,a.spacings.right,({$disabledText:e})=>e?a.states.disabled.typography.color:a.typography.color),u=l.span.withConfig({displayName:"Label__Text",componentId:"sc-1gi2bcn-1"})(["margin:0;"]),F=w.forwardRef(function(i,c){const{label:p="",meta:n,disabled:g=!1,...r}=i;return o.jsxs(M,{ref:c,$disabledText:g,...r,children:[o.jsx(u,{children:p}),n&&o.jsx(u,{children:n})]})}),{colors:s,spacings:{comfortable:{small:x,x_small:y}},typography:q,shape:A}=f,t={background:s.ui.background__light.rgba,typography:{...q.input.text,color:s.text.static_icons__default.rgba},entities:{input:{spacings:{left:x,right:x,top:"6px",bottom:"6px"}},icon:{width:"24px"}},boxShadow:"inset 0 -1px 0 0 "+s.text.static_icons__tertiary.rgba,states:{focus:{outline:{type:"outline",width:"2px",color:s.interactive.primary__resting.rgba,style:"solid",offset:"0px"}},disabled:{typography:{color:s.interactive.disabled__text.rgba}}},modes:{compact:{minHeight:A._modes.compact.straight.minHeight,entities:{input:{spacings:{left:y,right:y,top:"0",bottom:"0"}}}}}},D=l.div.withConfig({displayName:"NativeSelect__Container",componentId:"sc-82vb16-0"})(["min-width:100px;width:100%;"]),G=l.select.withConfig({displayName:"NativeSelect__StyledSelect",componentId:"sc-82vb16-1"})(["border:none;border-radius:0;box-shadow:",";"," "," padding-right:calc("," *2 + ",");display:block;margin:0;appearance:none;background-image:"," linear-gradient( to bottom,"," 0%,"," 100% );background-repeat:no-repeat,repeat;background-position:right "," top 50%;width:100%;&:active,&:focus{box-shadow:none;","}&:disabled{color:",`;background-image:url("data:image/svg+xml,%3Csvg width='24' height='24' viewBox='0 0 24 24' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath fill='%23bebebe' d='M7 9.5l5 5 5-5H7z'/%3E%3C/svg%3E"),linear-gradient( to bottom,`," 0%,"," 100% );cursor:not-allowed;box-shadow:none;outline:none;.arrow-icon{fill:red;}&:focus,&:active{outline:none;}}"],t.boxShadow,_(t.typography),({theme:e})=>P(["height:",";",""],e.minHeight,R(e.entities.input.spacings)),t.entities.input.spacings.right,t.entities.icon.width,e=>e.multiple?"":`url("data:image/svg+xml,%3Csvg width='24' height='24' viewBox='0 0 24 24' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath fill='%236f6f6f' d='M7 9.5l5 5 5-5H7z'/%3E%3C/svg%3E"),`,t.background,t.background,t.entities.input.spacings.right,$(t.states.focus.outline),t.states.disabled.typography.color,t.background,t.background),K=w.forwardRef(function({label:i,children:c,className:p,style:n,selectRef:g,id:r,meta:d,disabled:h=!1,multiple:v=!1,...k},C){const{density:j}=H(),S=B({density:j},t),E={ref:C,className:p,style:n},N={ref:g,id:r,disabled:h,multiple:v,...k},L={htmlFor:r,label:i,meta:d,disabled:h},T=i||d;return o.jsx(I,{theme:S,children:o.jsxs(D,{...E,children:[T&&o.jsx(F,{...L}),o.jsx(G,{...N,children:c})]})})});export{F as L,K as N};
