function i(r,e){return r.localeCompare(e,"no")}function l(r,e){const n=r.split(".").map(Number),s=e.split(".").map(Number);for(let t=0;t<Math.max(n.length,s.length);t++){const a=n[t]||0,o=s[t]||0;if(a<o)return!0;if(a>o)return!1}return!1}export{l as i,i as s};
