function n(e){return"short_identifier"in e?e.short_identifier:e.identifier}function r(e){let t="";return e.length&&(t=n(e[0]),e.length>1&&(t+=` (and ${String(e.length-1)} more)`)),t}function i(){return{identifier:"(none)",uuid:"0"}}function o(){return{coordinate_system:i(),country:[],discovery:[],field:[],stratigraphic_column:i()}}function a(e){return e.split("rms/model/").pop()??""}export{r as a,n as b,o as c,i as e,a as g};
